==> webkitgtk-1.11.5.tar.xz: webkitgtk-1.11.5/Source/WebCore/Modules/webdatabase/SQLTransactionClient.cpp <==
/*
 * Copyright (C) 2009 Google Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *     * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following disclaimer
 * in the documentation and/or other materials provided with the
 * distribution.
 *     * Neither the name of Google Inc. nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "SQLTransactionClient.h"

#if ENABLE(SQL_DATABASE)

#include "DatabaseBackend.h"
#include "DatabaseContext.h"
#include "DatabaseManager.h"
#include "ScriptExecutionContext.h"
#include "SecurityOrigin.h"

namespace WebCore {

void SQLTransactionClient::didCommitWriteTransaction(DatabaseBackend* database)
{
    DatabaseManager::manager().scheduleNotifyDatabaseChanged(
        database->securityOrigin(), database->stringIdentifier());
}

void SQLTransactionClient::didExecuteStatement(DatabaseBackend* database)
{
    DatabaseManager::manager().databaseChanged(database);
}

bool SQLTransactionClient::didExceedQuota(DatabaseBackend* database)
{
    ASSERT(database->scriptExecutionContext()->isContextThread());
    unsigned long long currentQuota = DatabaseManager::manager().quotaForOrigin(database->securityOrigin());
    database->databaseContext()->databaseExceededQuota(database->stringIdentifier(), database->details());
    unsigned long long newQuota = DatabaseManager::manager().quotaForOrigin(database->securityOrigin());
    return (newQuota > currentQuota);
}

}

#endif // ENABLE(SQL_DATABASE)

==> webkitgtk_2.4.11.orig.tar.xz: webkitgtk-2.4.11/Source/WebCore/Modules/webdatabase/SQLTransactionClient.cpp <==
/*
 * Copyright (C) 2009 Google Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *     * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following disclaimer
 * in the documentation and/or other materials provided with the
 * distribution.
 *     * Neither the name of Google Inc. nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "SQLTransactionClient.h"

#if ENABLE(SQL_DATABASE)

#include "DatabaseBackendBase.h"
#include "DatabaseBackendContext.h"
#include "DatabaseManager.h"
#include "DatabaseTracker.h"
#include "ScriptExecutionContext.h"
#include "SecurityOrigin.h"

namespace WebCore {

void SQLTransactionClient::didCommitWriteTransaction(DatabaseBackendBase* database)
{
    DatabaseTracker::tracker().scheduleNotifyDatabaseChanged(
        database->securityOrigin(), database->stringIdentifier());
}

bool SQLTransactionClient::didExceedQuota(DatabaseBackendBase* database)
{
    ASSERT(database->databaseContext()->scriptExecutionContext()->isContextThread());
    unsigned long long currentQuota = DatabaseManager::manager().quotaForOrigin(database->securityOrigin());
    database->databaseContext()->databaseExceededQuota(database->stringIdentifier(), database->details());
    unsigned long long newQuota = DatabaseManager::manager().quotaForOrigin(database->securityOrigin());
    return (newQuota > currentQuota);
}

}

#endif // ENABLE(SQL_DATABASE)
